==> knative-model-6.1.0-sources.jar: io/fabric8/knative/serving/v1beta1/DomainMappingFluentImpl.java <==
package io.fabric8.knative.serving.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class DomainMappingFluentImpl<A extends DomainMappingFluent<A>> extends BaseFluent<A> implements DomainMappingFluent<A>{
  public DomainMappingFluentImpl() {
  }
  public DomainMappingFluentImpl(DomainMapping instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private DomainMappingSpecBuilder spec;
  private DomainMappingStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public DomainMappingFluent.MetadataNested<A> withNewMetadata() {
    return new DomainMappingFluentImpl.MetadataNestedImpl();
  }
  public DomainMappingFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new DomainMappingFluentImpl.MetadataNestedImpl(item);
  }
  public DomainMappingFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public DomainMappingFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public DomainMappingFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public DomainMappingSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public DomainMappingSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(DomainMappingSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new DomainMappingSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public DomainMappingFluent.SpecNested<A> withNewSpec() {
    return new DomainMappingFluentImpl.SpecNestedImpl();
  }
  public DomainMappingFluent.SpecNested<A> withNewSpecLike(DomainMappingSpec item) {
    return new DomainMappingFluentImpl.SpecNestedImpl(item);
  }
  public DomainMappingFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public DomainMappingFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new DomainMappingSpecBuilder().build());
  }
  public DomainMappingFluent.SpecNested<A> editOrNewSpecLike(DomainMappingSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public DomainMappingStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public DomainMappingStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(DomainMappingStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new DomainMappingStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public DomainMappingFluent.StatusNested<A> withNewStatus() {
    return new DomainMappingFluentImpl.StatusNestedImpl();
  }
  public DomainMappingFluent.StatusNested<A> withNewStatusLike(DomainMappingStatus item) {
    return new DomainMappingFluentImpl.StatusNestedImpl(item);
  }
  public DomainMappingFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public DomainMappingFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new DomainMappingStatusBuilder().build());
  }
  public DomainMappingFluent.StatusNested<A> editOrNewStatusLike(DomainMappingStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    DomainMappingFluentImpl that = (DomainMappingFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<DomainMappingFluent.MetadataNested<N>> implements DomainMappingFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) DomainMappingFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends DomainMappingSpecFluentImpl<DomainMappingFluent.SpecNested<N>> implements DomainMappingFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(DomainMappingSpec item) {
      this.builder = new DomainMappingSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new DomainMappingSpecBuilder(this);
    }
    DomainMappingSpecBuilder builder;
    public N and() {
      return (N) DomainMappingFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends DomainMappingStatusFluentImpl<DomainMappingFluent.StatusNested<N>> implements DomainMappingFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(DomainMappingStatus item) {
      this.builder = new DomainMappingStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new DomainMappingStatusBuilder(this);
    }
    DomainMappingStatusBuilder builder;
    public N and() {
      return (N) DomainMappingFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/serving/v1beta1/DomainMappingFluentImpl.java <==
package io.fabric8.knative.serving.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class DomainMappingFluentImpl<A extends DomainMappingFluent<A>> extends BaseFluent<A> implements DomainMappingFluent<A>{
  public DomainMappingFluentImpl() {
  }
  public DomainMappingFluentImpl(DomainMapping instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private DomainMappingSpecBuilder spec;
  private DomainMappingStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public DomainMappingFluentImpl.MetadataNested<A> withNewMetadata() {
    return new DomainMappingFluentImpl.MetadataNestedImpl();
  }
  public DomainMappingFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new DomainMappingFluentImpl.MetadataNestedImpl(item);
  }
  public DomainMappingFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public DomainMappingFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public DomainMappingFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public DomainMappingSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public DomainMappingSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(DomainMappingSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new DomainMappingSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public DomainMappingFluentImpl.SpecNested<A> withNewSpec() {
    return new DomainMappingFluentImpl.SpecNestedImpl();
  }
  public DomainMappingFluentImpl.SpecNested<A> withNewSpecLike(DomainMappingSpec item) {
    return new DomainMappingFluentImpl.SpecNestedImpl(item);
  }
  public DomainMappingFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public DomainMappingFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new DomainMappingSpecBuilder().build());
  }
  public DomainMappingFluentImpl.SpecNested<A> editOrNewSpecLike(DomainMappingSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public DomainMappingStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public DomainMappingStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(DomainMappingStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new DomainMappingStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public DomainMappingFluentImpl.StatusNested<A> withNewStatus() {
    return new DomainMappingFluentImpl.StatusNestedImpl();
  }
  public DomainMappingFluentImpl.StatusNested<A> withNewStatusLike(DomainMappingStatus item) {
    return new DomainMappingFluentImpl.StatusNestedImpl(item);
  }
  public DomainMappingFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public DomainMappingFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new DomainMappingStatusBuilder().build());
  }
  public DomainMappingFluentImpl.StatusNested<A> editOrNewStatusLike(DomainMappingStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DomainMappingFluentImpl that = (DomainMappingFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<DomainMappingFluentImpl.MetadataNested<N>> implements DomainMappingFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) DomainMappingFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends DomainMappingSpecFluentImpl<DomainMappingFluentImpl.SpecNested<N>> implements DomainMappingFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(DomainMappingSpec item) {
      this.builder = new DomainMappingSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new DomainMappingSpecBuilder(this);
    }
    DomainMappingSpecBuilder builder;
    public N and() {
      return (N) DomainMappingFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends DomainMappingStatusFluentImpl<DomainMappingFluentImpl.StatusNested<N>> implements DomainMappingFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(DomainMappingStatus item) {
      this.builder = new DomainMappingStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new DomainMappingStatusBuilder(this);
    }
    DomainMappingStatusBuilder builder;
    public N and() {
      return (N) DomainMappingFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
